==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/bd/gbd05.h <==
/****************************************************************************

  module      : gbd05.h

  -------------------------------------------------------------------------

  responsible : AlexanderK

  special area: general classes used in BD
  description : description ...


  last changed: 1999-09-06  17:01
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin  GPL
    Copyright (C) 2000 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end

*****************************************************************************/


#ifndef GBD05_H
#define GBD05_H

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"
#include "ggg00.h"
#include "gbd00.h"

#include "hbd30_1.h"
#include "hbd01_1.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/

/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/

/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/

class cbd05_Current : public tbd_current_tree
{
public:
	cbd05_Current (){};

    cbd05_Current (tgg00_TransContext &Trans,
                   tgg00_MessType_Enum MessType);

	cbd05_Current (tgg00_TransContext  &Trans, 
	               tgg00_MessType_Enum  MessType,
	               tgg00_FileId        &FileId);

	void bd05SetCurrent (tgg00_TransContext  &Trans, 
				    	 tgg00_MessType_Enum  MessType);

	void bd05SetCurrent (tgg00_TransContext  &Trans, 
	                     tgg00_MessType_Enum  MessType,
	                     tgg00_FileId        &FileId);

};

/*===========================================================================*
 *  DEFINITION OF METHODS                                                    *
 *===========================================================================*/

inline void 
cbd05_Current::bd05SetCurrent (tgg00_TransContext  &Trans, 
							   tgg00_MessType_Enum  MessType)
{
	b30cinit_current (Trans, *this);
	curr_action  = (tgg00_MessType::fromConst(MessType));
}

/*---------------------------------------------------------------------------*/

inline void 
cbd05_Current::bd05SetCurrent (tgg00_TransContext  &Trans, 
							   tgg00_MessType_Enum  MessType,
							   tgg00_FileId        &FileId)
{
    bd05SetCurrent (Trans,  MessType);
	curr_tree_id = FileId;
}

/*---------------------------------------------------------------------------*/
inline
cbd05_Current::cbd05_Current (tgg00_TransContext     &Trans, 
							  tgg00_MessType_Enum     MessType)
//:tbd_current_tree (b01nilcurrent) /* PTS 1105458 AK 26/01/2000 */ 
{
	memcpy (STATIC_CAST (tbd_current_tree*,this), &b01nilcurrent, sizeof (b01nilcurrent)); 
	curr_action = (tgg00_MessType::fromConst(MessType));
    curr_trans  = &Trans;
}

/*---------------------------------------------------------------------------*/
inline
cbd05_Current::cbd05_Current (tgg00_TransContext  &Trans, 
					    	  tgg00_MessType_Enum  MessType,
							  tgg00_FileId        &FileId)
:tbd_current_tree (b01nilcurrent)
{
	curr_action  = (tgg00_MessType::fromConst(MessType));
    curr_trans   = &Trans;
	curr_tree_id = FileId;
}

/*---------------------------------------------------------------------------*/

#endif  /* GBD05_H */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/bd/gbd05.h <==
/****************************************************************************

  module      : gbd05.h

  -------------------------------------------------------------------------

  responsible : AlexanderK

  special area: general classes used in BD
  description : description ...


  last changed: 1999-09-06  17:01
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin  GPL
    Copyright (C) 2000 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end

*****************************************************************************/


#ifndef GBD05_H
#define GBD05_H

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"
#include "ggg00.h"
#include "gbd00.h"

#include "hbd30_1.h"
#include "hbd01_1.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/

/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/

/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/

class cbd05_Current : public tbd_current_tree
{
public:
	cbd05_Current (){};

    cbd05_Current (tgg00_TransContext &Trans,
                   tgg00_MessType_Enum MessType);

	cbd05_Current (tgg00_TransContext   &Trans, 
	               tgg00_MessType_Enum   MessType,
	               const tgg00_FileId   &FileId);

	void bd05SetCurrent (tgg00_TransContext  &Trans, 
				    	 tgg00_MessType_Enum  MessType);

	void bd05SetCurrent (tgg00_TransContext    &Trans, 
	                     tgg00_MessType_Enum    MessType,
	                     const tgg00_FileId    &FileId);

};

/*===========================================================================*
 *  DEFINITION OF METHODS                                                    *
 *===========================================================================*/

inline void 
cbd05_Current::bd05SetCurrent (tgg00_TransContext  &Trans, 
							   tgg00_MessType_Enum  MessType)
{
	b30cinit_current (Trans, *this);
	curr_action  = (tgg00_MessType::fromConst(MessType));
}

/*---------------------------------------------------------------------------*/

inline void 
cbd05_Current::bd05SetCurrent (tgg00_TransContext   &Trans, 
							   tgg00_MessType_Enum   MessType,
							   const tgg00_FileId   &FileId)
{
    bd05SetCurrent (Trans,  MessType);
	curr_tree_id = FileId;
}

/*---------------------------------------------------------------------------*/
inline
cbd05_Current::cbd05_Current (tgg00_TransContext     &Trans, 
							  tgg00_MessType_Enum     MessType)
//:tbd_current_tree (b01nilcurrent) /* PTS 1105458 AK 26/01/2000 */ 
{
	memcpy (STATIC_CAST (tbd_current_tree*,this), &b01nilcurrent, sizeof (b01nilcurrent)); 
	curr_action = (tgg00_MessType::fromConst(MessType));
    curr_trans  = &Trans;
}

/*---------------------------------------------------------------------------*/
inline
cbd05_Current::cbd05_Current (tgg00_TransContext   &Trans, 
					    	  tgg00_MessType_Enum   MessType,
							  const tgg00_FileId   &FileId)
:tbd_current_tree (b01nilcurrent)
{
	curr_action  = (tgg00_MessType::fromConst(MessType));
    curr_trans   = &Trans;
	curr_tree_id = FileId;
}

/*---------------------------------------------------------------------------*/

#endif  /* GBD05_H */
